==> webkit2gtk_2.50.3.orig.tar.xz: webkitgtk-2.50.3/Source/WebCore/platform/graphics/MediaSourcePrivateClient.h <==
/*
 * Copyright (C) 2013-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(MEDIA_SOURCE)

#include "MediaPromiseTypes.h"
#include "PlatformTimeRanges.h"
#include <wtf/CompletionHandler.h>
#include <wtf/Forward.h>
#include <wtf/Logger.h>
#include <wtf/ThreadSafeWeakPtr.h>

namespace WebCore {

class MediaSourcePrivate;

class MediaSourcePrivateClient : public ThreadSafeRefCountedAndCanMakeThreadSafeWeakPtr<MediaSourcePrivateClient> {
public:
    virtual ~MediaSourcePrivateClient() = default;

    virtual void setPrivateAndOpen(Ref<MediaSourcePrivate>&&) = 0;
    virtual void reOpen() = 0;
    virtual Ref<MediaTimePromise> waitForTarget(const SeekTarget&) = 0;
    virtual Ref<MediaPromise> seekToTime(const MediaTime&) = 0;
    virtual RefPtr<MediaSourcePrivate> mediaSourcePrivate() const = 0;

#if !RELEASE_LOG_DISABLED
    virtual void setLogIdentifier(uint64_t) = 0;
    virtual const Logger* logger() const { return nullptr; }
#endif

    enum class RendererType { Audio, Video };
    virtual void failedToCreateRenderer(RendererType) = 0;
};

}

#endif // ENABLE(MEDIA_SOURCE)

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebCore/platform/graphics/MediaSourcePrivateClient.h <==
/*
 * Copyright (C) 2013-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(MEDIA_SOURCE)

#include <WebCore/MediaPromiseTypes.h>
#include <WebCore/PlatformTimeRanges.h>
#include <wtf/CompletionHandler.h>
#include <wtf/Forward.h>
#include <wtf/Logger.h>
#include <wtf/ThreadSafeWeakPtr.h>

namespace WebCore {

class MediaSourcePrivate;

class MediaSourcePrivateClient : public ThreadSafeRefCountedAndCanMakeThreadSafeWeakPtr<MediaSourcePrivateClient> {
public:
    virtual ~MediaSourcePrivateClient() = default;

    virtual void setPrivateAndOpen(Ref<MediaSourcePrivate>&&) = 0;
    virtual void reOpen() = 0;
    virtual Ref<MediaTimePromise> waitForTarget(const SeekTarget&) = 0;
    virtual RefPtr<MediaSourcePrivate> mediaSourcePrivate() const = 0;

#if !RELEASE_LOG_DISABLED
    virtual void setLogIdentifier(uint64_t) = 0;
    virtual const Logger* logger() const { return nullptr; }
#endif

    enum class RendererType { Audio, Video };
    virtual void failedToCreateRenderer(RendererType) = 0;
};

}

#endif // ENABLE(MEDIA_SOURCE)
